@@ -8,7 +8,7 @@ includedir=${prefix}/include
 libdir=${exec_prefix}/lib
 
 XML2_LIBDIR="-L${libdir}"
-XML2_LIBS="-lxml2 -lz  -lgiconv -lm -L/usr/local/lib"
+XML2_LIBS="-lxml2 -lz  -lm -L/usr/local/lib"
 XML2_INCLUDEDIR="-I${includedir}/libxml2/libxml -I${includedir}/libxml2"
-MODULE_VERSION="xml2-2.4.6"
+MODULE_VERSION="xml2-2.4.10"
 
