@@ -26,21 +26,21 @@ extern void xmlCheckVersion(int version);
  *
  * the version string like "1.2.3"
  */
-#define LIBXML_DOTTED_VERSION "2.4.1"
+#define LIBXML_DOTTED_VERSION "2.4.10"
 
 /**
  * LIBXML_VERSION:
  *
  * the version number: 1.2.3 value is 1002003
  */
-#define LIBXML_VERSION 20401
+#define LIBXML_VERSION 20410
 
 /**
  * LIBXML_VERSION_STRING:
  *
  * the version number string, 1.2.3 value is "1002003"
  */
-#define LIBXML_VERSION_STRING "20401"
+#define LIBXML_VERSION_STRING "20410"
 
 /**
  * LIBXML_TEST_VERSION:
@@ -48,15 +48,37 @@ extern void xmlCheckVersion(int version);
  * Macro to check that the libxml version in use is compatible with
  * the version the software has been compiled against
  */
-#define LIBXML_TEST_VERSION xmlCheckVersion(20401);
+#define LIBXML_TEST_VERSION xmlCheckVersion(20410);
 
+#ifndef VMS
+#if 0
 /**
  * WITH_TRIO:
  *
- * Whether the trio support need to be configured in
+ * defined if the trio support need to be configured in
+ */
+#define WITH_TRIO
+#else
+/**
+ * WITHOUT_TRIO:
+ *
+ * defined if the trio support should not be configured in
+ */
+#define WITHOUT_TRIO
+#endif
+#else /* VMS */
+#define WITH_TRIO 1
+#endif /* VMS */
+
+/**
+ * LIBXML_THREADS_ENABLED:
+ *
+ * Whether the thread support is configured in
  */
 #if 0
-#define WITH_TRIO
+#if defined(_REENTRANT) || (_POSIX_C_SOURCE - 0 >= 199506L)
+#define LIBXML_THREAD_ENABLED
+#endif
 #endif
 
 /**
@@ -163,10 +185,20 @@ extern void xmlCheckVersion(int version);
 /**
  * LIBXML_DLL_IMPORT:
  *
- * Used on Windows to declare a variable as exported by the library
+ * Used on Windows (MS C compiler only) to declare a variable as 
+ * imported from the library. This macro should be empty when compiling
+ * libxml itself. It should expand to __declspec(dllimport)
+ * when the client code includes this header, and that only if the client
+ * links dynamically against libxml.
+ * For this to work, we need three macros. One tells us which compiler is
+ * being used and luckily the compiler defines such a thing: _MSC_VER. The
+ * second macro tells us if we are compiling libxml or the client code and
+ * we define the macro IN_LIBXML on the compiler's command line for this 
+ * purpose. The third macro, LIBXML_STATIC, must be defined by any client 
+ * code which links against libxml statically. 
  */
 #ifndef LIBXML_DLL_IMPORT
-#if defined(WIN32) && !defined(STATIC)
+#if defined(_MSC_VER) && !defined(IN_LIBXML) && !defined(LIBXML_STATIC)
 #define LIBXML_DLL_IMPORT __declspec(dllimport)
 #else
 #define LIBXML_DLL_IMPORT
